@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Lite;
 
 our $DATE = '2017-06-19'; # DATE
-our $VERSION = '1.74_001'; # VERSION
+our $VERSION = '1.74_002'; # VERSION
 
 use 5.010001;
 # use strict; # already enabled by Mo
@@ -523,7 +523,7 @@ Perinci::CmdLine::Lite - A Rinci/Riap-based command-line application framework
 
 =head1 VERSION
 
-This document describes version 1.74_001 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2017-06-19.
+This document describes version 1.74_002 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2017-06-19.
 
 =head1 SYNOPSIS
 
@@ -680,9 +680,8 @@ Whether to enable logging. This currently means setting up L<Log::Any::Adapter>
 to display logging (set in C<hook_after_parse_argv>, so tab completion skips
 this step). To produce log, you use L<Log::Any> in your code.
 
-The default is off. If you set LOG=1 or LOG_LEVEL or TRACE/DEBUG/VERBOSE/QUIET,
-then the default will be on. It defaults to off if you set LOG=0 or
-LOG_LEVEL=off.
+The default is off. If you set LOG_LEVEL or TRACE/DEBUG/VERBOSE/QUIET, then the
+default will be on. It defaults to off if you set LOG_LEVEL=off.
 
 =head2 log_level => str (default: from env, or 'warning')
 
